@@ -84,15 +84,4 @@ L<MojoX::Session>
 
 L<Mojolicious>
 
-=head1 AUTHOR
-
-vti, C<vti@cpan.org>.
-
-=head1 COPYRIGHT
-
-Copyright (C) 2009, Viacheslav Tykhanovskyi.
-
-This program is free software, you can redistribute it and/or modify it under
-the same terms as Perl 5.10.
-
 =cut
